Provides a pure interface for the Telegram Bot API. In addition to the pure API implementation, it features a number of tools to make the development of Telegram bots with R easy and straightforward, providing an easy-to-use interface that takes some work off the programmer.
UpdaterPackage main class. This class,
which employs the class Dispatcher, provides a front-end to
class Bot to the programmer, so they can focus on coding the bot.
Its purpose is to receive the updates from Telegram and to deliver them to said
dispatcher.
DispatcherThis class dispatches all kinds of updates to its registered handlers.
HandlerThe base class for all update handlers.
BotThis object represents a Telegram Bot.
In this page you can learn how to build a Bot quickly with this package.